@@ -18,7 +18,7 @@ import logging
 import os
 
 from django.utils.safestring import mark_safe
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon import exceptions
 from horizon import messages
@@ -106,10 +106,7 @@ class JSONMessage(object):
 
 
 def _is_path(path):
-    if os.path.exists(path) and os.path.isdir(path):
-        return True
-    else:
-        return False
+    return os.path.exists(path) and os.path.isdir(path)
 
 
 def _get_processed_messages(messages_path):
@@ -143,8 +140,8 @@ def process_message_notification(request, messages_path):
     # NOTE (lhcheng): Cache the processed messages to avoid parsing
     # the files every time. Check directory modification time if
     # reload is necessary.
-    if (_MESSAGES_CACHE is None
-            or _MESSAGES_MTIME != os.path.getmtime(messages_path)):
+    if (_MESSAGES_CACHE is None or
+            _MESSAGES_MTIME != os.path.getmtime(messages_path)):
         _MESSAGES_CACHE = _get_processed_messages(messages_path)
         _MESSAGES_MTIME = os.path.getmtime(messages_path)
 
