@@ -25,7 +25,7 @@ from django.template.loader import render_to_string
 from django import urls
 from django.utils.functional import Promise
 from django.utils.http import urlencode
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon import exceptions
 from horizon import messages
