@@ -17,7 +17,7 @@
 #    under the License.
 
 from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from novaclient import exceptions as nova_exceptions
 
 from horizon import exceptions
