@@ -16,9 +16,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.core.urlresolvers import reverse
+from unittest import mock
 
-import mock
+from django.urls import reverse
 
 from openstack_dashboard import api
 from openstack_dashboard.test import helpers as test
