@@ -13,8 +13,8 @@
 #   under the License.
 
 
+from django.utils.translation import gettext_lazy as _
 from django.utils.translation import pgettext_lazy
-from django.utils.translation import ugettext_lazy as _
 
 from horizon import tables
 from horizon.utils import filters
