@@ -12,10 +12,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from unittest import mock
+
 import django.test
 from django.urls import reverse
 
-import mock
 from oslo_serialization import jsonutils
 
 from openstack_dashboard import api
@@ -233,17 +234,3 @@ class NetworkTopologyCreateTests(test.TestCase):
 
         self._test_new_button_disabled_when_quota_exceeded(expected_string,
                                                            routers_quota=0)
-
-    @test.update_settings(LAUNCH_INSTANCE_LEGACY_ENABLED=True)
-    @test.create_mocks({quotas: ('tenant_quota_usages',)})
-    def test_launch_instance_button_disabled_when_quota_exceeded(self):
-        url = reverse('horizon:project:network_topology:launchinstance')
-        classes = 'btn btn-default btn-launch ajax-modal'
-        link_name = "Launch Instance (Quota exceeded)"
-        expected_string = "<a href='%s' class='%s disabled' "\
-            "id='instances__action_launch'>" \
-            "<span class='fa fa-cloud-upload'></span>%s</a>" \
-            % (url, classes, link_name)
-
-        self._test_new_button_disabled_when_quota_exceeded(expected_string,
-                                                           instances_quota=0)
