@@ -16,7 +16,7 @@
 Views for managing Neutron Subnets.
 """
 from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon import exceptions
 from horizon import tabs
