@@ -11,9 +11,9 @@
 #    under the License.
 
 from django.urls import reverse
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 from django.utils.translation import pgettext_lazy
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy
 
 from horizon import exceptions
 from horizon import tables
@@ -36,7 +36,7 @@ class DeleteGroupSnapshot(policy.PolicyTargetMixin, tables.DeleteAction):
 
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Delete Snapshot",
             "Delete Snapshots",
             count
@@ -44,7 +44,7 @@ class DeleteGroupSnapshot(policy.PolicyTargetMixin, tables.DeleteAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Scheduled deletion of Snapshot",
             "Scheduled deletion of Snapshots",
             count
