@@ -87,21 +87,45 @@ def is_prev_link_available(driver):
 
 
 def get_table_definition(driver, sorting=False):
-    names = driver.find_elements_by_css_selector('table tr td:nth-child(2)')
-    if sorting:
-        names.sort()
-    actual_table = TableDefinition(next=is_next_link_available(driver),
-                                   prev=is_prev_link_available(driver),
-                                   count=len(names), names=[names[0].text])
-    return actual_table
+    try:
+        names = driver.find_elements_by_css_selector('table tr td:nth-child(2)')
+        if sorting:
+            names.sort()
+        actual_table = TableDefinition(next=is_next_link_available(driver),
+                                       prev=is_prev_link_available(driver),
+                                       count=len(names), names=[names[0].text])
+        return actual_table
+    except exceptions.WebDriverException:
+        return None
 
 
 def get_image_table_definition(driver, sorting=False):
     """This function is specific to Image table definition"""
-    names = driver.find_elements_by_css_selector("td[class='rsp-p1 word-wrap']")
-    if sorting:
-        names.sort()
-    actual_table = TableDefinition(next=is_next_link_available(driver),
-                                   prev=is_prev_link_available(driver),
-                                   count=len(names), names=[names[0].text])
-    return actual_table
+    try:
+        names = driver.find_elements_by_css_selector(
+            "td[class='rsp-p1 word-wrap']")
+        if sorting:
+            names.sort()
+        actual_table = TableDefinition(next=is_next_link_available(driver),
+                                       prev=is_prev_link_available(driver),
+                                       count=len(names), names=[names[0].text])
+        return actual_table
+    except (exceptions.WebDriverException, IndexError):
+        return None
+
+
+def select_from_transfer_table(element, label):
+    #   Choose row from available Images, Flavors, Networks, etc.
+    #   In launch tab for example: m1.tiny for Flavor, cirros for image, etc.
+
+    try:
+        element.find_element_by_xpath(
+            f".//*[text()='{label}']//ancestor::tr/td//*"
+            f"[@class='btn btn-default fa fa-arrow-up']").click()
+    except exceptions.NoSuchElementException:
+        try:
+            element.find_element_by_xpath(
+                f".//*[text()='{label}']//ancestor::tr/td//*"
+                f"[@class='btn btn-default fa fa-arrow-down']")
+        except exceptions.NoSuchElementException:
+            raise
